# Welcome to the Semantic World Package

The semantic world is a Python package for querying and manipulating robot simulation data.  
It originates from PyCRAM's abstract world and unifies the functionality needed by multiple packages.

# User Installation


You can install the package directly from PyPI:

```bash
pip install -U semantic_world
```

# Contributing

If you are interested in contributing, you can check out the source code from GitHub:

```bash
git clone https://github.com/cram2/semantic_world.git
```

# Tests
The tests can be run using `pytest` after installing the package.

```bash
pytest test/
```

# Documentation

You can read the official documentation [here](https://cram2.github.io/semantic_world/intro.html)!